@@ -157,6 +157,9 @@ sub cmd_bundle {
     );
     $builder->bundle($env->install_path, $env->vendor_cache, $env->snapshot);
 
+    require Carton::Packer;
+    Carton::Packer->new->fatpack_carton($env->vendor_bin);
+
     $self->printf("Complete! Modules were bundled into %s\n", $env->vendor_cache, SUCCESS);
 }
 
@@ -360,7 +363,7 @@ sub cmd_exec {
 
     while (@args) {
         if ($args[0] eq '-I') {
-            warn "exec -Ilib is deprecated. Just run the following command with -I.\n";
+            warn "exec -Ilib is deprecated. You might want to run: carton exec perl -Ilib ...\n";
             splice(@args, 0, 2);
         } else {
             last;
